<?php
// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

// Overwrite parent theme background defaults and registers support for WordPress features.
add_action( 'after_setup_theme', 'lalita_background_setup' );
function lalita_background_setup() {
	add_theme_support( "custom-background",
		array(
			'default-color' 		 => 'd9d56a',
			'default-image'          => '',
			'default-repeat'         => 'repeat',
			'default-position-x'     => 'left',
			'default-position-y'     => 'top',
			'default-size'           => 'auto',
			'default-attachment'     => '',
			'wp-head-callback'       => '_custom_background_cb',
			'admin-head-callback'    => '',
			'admin-preview-callback' => ''
		)
	);
}

// Overwrite theme URL
function lalita_theme_uri_link() {
	return 'https://wpkoi.com/sundara-wpkoi-wordpress-theme/';
}

// Overwrite parent theme's blog header function
add_action( 'lalita_after_header', 'lalita_blog_header_image', 11 );
function lalita_blog_header_image() {

	if ( ( is_front_page() && is_home() ) || ( is_home() ) ) { 
		$blog_header_image 			=  lalita_get_setting( 'blog_header_image' ); 
		$blog_header_title 			=  lalita_get_setting( 'blog_header_title' ); 
		$blog_header_text 			=  lalita_get_setting( 'blog_header_text' ); 
		$blog_header_button_text 	=  lalita_get_setting( 'blog_header_button_text' ); 
		$blog_header_button_url 	=  lalita_get_setting( 'blog_header_button_url' ); 
		if ( $blog_header_image != '' ) { ?>
		<div class="page-header-image grid-parent page-header-blog" style="background-image: url('<?php echo esc_url($blog_header_image); ?>') !important;">
        	<div class="page-header-noiseoverlay"></div>
        	<div class="page-header-blog-inner">
                <div class="page-header-blog-content-h grid-container">
                    <div class="page-header-blog-content">
                    <?php if ( $blog_header_title != '' ) { ?>
                        <div class="page-header-blog-text">
                            <?php if ( $blog_header_title != '' ) { ?>
                            <h2><?php echo wp_kses_post( $blog_header_title ); ?></h2>
                            <div class="clearfix"></div>
                            <?php } ?>
                        </div>
                    <?php } ?>
                    </div>
                </div>
                <div class="page-header-blog-content page-header-blog-content-b">
                	<?php if ( $blog_header_text != '' ) { ?>
                	<div class="page-header-blog-text">
						<?php if ( $blog_header_title != '' ) { ?>
                        <p><?php echo wp_kses_post( $blog_header_text ); ?></p>
                        <div class="clearfix"></div>
                        <?php } ?>
                    </div>
                    <?php } ?>
                    <div class="page-header-blog-button">
                        <?php if ( $blog_header_button_text != '' ) { ?>
                        <a class="read-more button" href="<?php echo esc_url( $blog_header_button_url ); ?>"><?php echo esc_html( $blog_header_button_text ); ?></a>
                        <?php } ?>
                    </div>
                </div>
            </div>
		</div>
		<?php
		}
	}
}

// Extra cutomizer functions
if ( ! function_exists( 'sundara_customize_register' ) ) {
	add_action( 'customize_register', 'sundara_customize_register' );
	function sundara_customize_register( $wp_customize ) {
				
		// Add Sundara customizer section
		$wp_customize->add_section(
			'sundara_layout_effects',
			array(
				'title' => __( 'Sundara Effects', 'sundara' ),
				'priority' => 24,
			)
		);
		
		
		// Page Gradient
		$wp_customize->add_setting(
			'sundara_settings[page_gradient]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'sundara_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'sundara_settings[page_gradient]',
			array(
				'type' => 'select',
				'label' => __( 'Page Gradient', 'sundara' ),
				'choices' => array(
					'enable' => __( 'Enable', 'sundara' ),
					'disable' => __( 'Disable', 'sundara' )
				),
				'settings' => 'sundara_settings[page_gradient]',
				'section' => 'sundara_layout_effects',
				'priority' => 1
			)
		);
		
		// Sundara gradient colors
		$wp_customize->add_setting(
			'sundara_settings[sundara_color_1]', array(
				'default' => '#ff552c',
				'type' => 'option',
				'sanitize_callback' => 'sundara_sanitize_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				'sundara_settings[sundara_color_1]',
				array(
					'label' => __( 'Gradient color 1', 'sundara' ),
					'section' => 'sundara_layout_effects',
					'settings' => 'sundara_settings[sundara_color_1]',
					'priority' => 5
				)
			)
		);
		
		$wp_customize->add_setting(
			'sundara_settings[sundara_color_2]', array(
				'default' => '#d9d56a',
				'type' => 'option',
				'sanitize_callback' => 'sundara_sanitize_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				'sundara_settings[sundara_color_2]',
				array(
					'label' => __( 'Gradient color 2', 'sundara' ),
					'section' => 'sundara_layout_effects',
					'settings' => 'sundara_settings[sundara_color_2]',
					'priority' => 6
				)
			)
		);
		
		$wp_customize->add_setting(
			'sundara_settings[sundara_color_3]', array(
				'default' => '#1d6ba9',
				'type' => 'option',
				'sanitize_callback' => 'sundara_sanitize_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				'sundara_settings[sundara_color_3]',
				array(
					'label' => __( 'Gradient color 3', 'sundara' ),
					'section' => 'sundara_layout_effects',
					'settings' => 'sundara_settings[sundara_color_3]',
					'priority' => 7
				)
			)
		);
		
		// Sidebar gradient
		$wp_customize->add_setting(
			'sundara_settings[sidebar_gradient]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'sundara_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'sundara_settings[sidebar_gradient]',
			array(
				'type' => 'select',
				'label' => __( 'Sidebar gradient', 'sundara' ),
				'choices' => array(
					'enable' => __( 'Enable', 'sundara' ),
					'disable' => __( 'Disable', 'sundara' )
				),
				'settings' => 'sundara_settings[sidebar_gradient]',
				'section' => 'sundara_layout_effects',
				'priority' => 10
			)
		);
		
		// Sundara gradient colors
		$wp_customize->add_setting(
			'sundara_settings[sundara_color_4]', array(
				'default' => '#634579',
				'type' => 'option',
				'sanitize_callback' => 'sundara_sanitize_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				'sundara_settings[sundara_color_4]',
				array(
					'label' => __( 'Gradient color 4', 'sundara' ),
					'section' => 'sundara_layout_effects',
					'settings' => 'sundara_settings[sundara_color_4]',
					'priority' => 15
				)
			)
		);
		
		$wp_customize->add_setting(
			'sundara_settings[sundara_color_5]', array(
				'default' => '#fa565d',
				'type' => 'option',
				'sanitize_callback' => 'sundara_sanitize_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				'sundara_settings[sundara_color_5]',
				array(
					'label' => __( 'Gradient color 5', 'sundara' ),
					'section' => 'sundara_layout_effects',
					'settings' => 'sundara_settings[sundara_color_5]',
					'priority' => 16
				)
			)
		);
		
		// Blog image shadow
		$wp_customize->add_setting(
			'sundara_settings[blog_shadow]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'sundara_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'sundara_settings[blog_shadow]',
			array(
				'type' => 'select',
				'label' => __( 'Blog image shadow', 'sundara' ),
				'choices' => array(
					'enable' => __( 'Enable', 'sundara' ),
					'disable' => __( 'Disable', 'sundara' )
				),
				'settings' => 'sundara_settings[blog_shadow]',
				'section' => 'sundara_layout_effects',
				'priority' => 30
			)
		);
		
		// Unique scrollbar
		$wp_customize->add_setting(
			'sundara_settings[unique_scrollbar]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'sundara_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'sundara_settings[unique_scrollbar]',
			array(
				'type' => 'select',
				'label' => __( 'Unique scrollbar', 'sundara' ),
				'choices' => array(
					'enable' => __( 'Enable', 'sundara' ),
					'disable' => __( 'Disable', 'sundara' )
				),
				'settings' => 'sundara_settings[unique_scrollbar]',
				'section' => 'sundara_layout_effects',
				'priority' => 40
			)
		);
		
		
		
	}
}

//Sanitize choices.
if ( ! function_exists( 'sundara_sanitize_choices' ) ) {
	function sundara_sanitize_choices( $input, $setting ) {
		// Ensure input is a slug
		$input = sanitize_key( $input );

		// Get list of choices from the control
		// associated with the setting
		$choices = $setting->manager->get_control( $setting->id )->choices;

		// If the input is a valid key, return it;
		// otherwise, return the default
		return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
	}
}

// Sanitize colors. Allow blank value.
if ( ! function_exists( 'sundara_sanitize_hex_color' ) ) {
	function sundara_sanitize_hex_color( $color ) {
	    if ( '' === $color ) {
	        return '';
		}

	    // 3 or 6 hex digits, or the empty string.
	    if ( preg_match('|^#([A-Fa-f0-9]{3}){1,2}$|', $color ) ) {
	        return $color;
		}

	    return '';
	}
}

// Sundara effects colors css
if ( ! function_exists( 'sundara_effect_colors_css' ) ) {
	function sundara_effect_colors_css() {
		// Get Customizer settings
		$sundara_settings = get_option( 'sundara_settings' );
		
		$sundara_color_1  	 = '#ff552c';
		$sundara_color_2  	 = '#d9d56a';
		$sundara_color_3  	 = '#1d6ba9';
		$sundara_color_4  	 = '#634579';
		$sundara_color_5  	 = '#fa565d';
		if ( isset( $sundara_settings['sundara_color_1'] ) ) {
			$sundara_color_1 = $sundara_settings['sundara_color_1'];
		}
		if ( isset( $sundara_settings['sundara_color_2'] ) ) {
			$sundara_color_2 = $sundara_settings['sundara_color_2'];
		}
		if ( isset( $sundara_settings['sundara_color_3'] ) ) {
			$sundara_color_3 = $sundara_settings['sundara_color_3'];
		}
		if ( isset( $sundara_settings['sundara_color_4'] ) ) {
			$sundara_color_4 = $sundara_settings['sundara_color_4'];
		}
		if ( isset( $sundara_settings['sundara_color_5'] ) ) {
			$sundara_color_5 = $sundara_settings['sundara_color_5'];
		}
		
		$lalita_settings = wp_parse_args(
			get_option( 'lalita_settings', array() ),
			lalita_get_defaults()
		);
		
		$sundara_extracolors = '.sundara-page-gradient #page {background-image: linear-gradient(' . esc_attr( $sundara_color_1 ) . ', ' . esc_attr( $sundara_color_2 ) . ', ' . esc_attr( $sundara_color_3 ) . ');}.sundara-sidebar-gradient #right-sidebar, .sundara-sidebar-gradient #left-sidebar {background-image: linear-gradient(' . esc_attr( $sundara_color_4 ) . ', ' . esc_attr( $sundara_color_5 ) . ');}.sundara-unique-scrollbar::-webkit-scrollbar-track {background: ' . esc_attr( $lalita_settings[ 'text_color' ] ) . ';}.sundara-unique-scrollbar::-webkit-scrollbar-thumb {background-image: linear-gradient(' . esc_attr( $sundara_color_4 ) . ', ' . esc_attr( $sundara_color_5 ) . ');border-color: ' . esc_attr( $lalita_settings[ 'text_color' ] ) . ';}.sundara-unique-scrollbar::-webkit-scrollbar-thumb:hover {background: #' . esc_attr( get_background_color() ) . ';}';
		
		return $sundara_extracolors;
	}
}


// The dynamic styles of the parent theme added inline to the parent stylesheet.
// For the customizer functions it is better to enqueue after the child theme stylesheet.
if ( ! function_exists( 'sundara_remove_parent_dynamic_css' ) ) {
	add_action( 'init', 'sundara_remove_parent_dynamic_css' );
	function sundara_remove_parent_dynamic_css() {
		remove_action( 'wp_enqueue_scripts', 'lalita_enqueue_dynamic_css', 50 );
	}
}

// Enqueue this CSS after the child stylesheet, not after the parent stylesheet.
if ( ! function_exists( 'sundara_enqueue_parent_dynamic_css' ) ) {
	add_action( 'wp_enqueue_scripts', 'sundara_enqueue_parent_dynamic_css', 50 );
	function sundara_enqueue_parent_dynamic_css() {
		$css = lalita_base_css() . lalita_font_css() . lalita_advanced_css() . lalita_spacing_css() . lalita_no_cache_dynamic_css() .sundara_effect_colors_css();

		// escaped secure before in parent theme
		wp_add_inline_style( 'lalita-child', $css );
	}
}

//Adds custom classes to the array of body classes.
if ( ! function_exists( 'sundara_body_classes' ) ) {
	add_filter( 'body_class', 'sundara_body_classes' );
	function sundara_body_classes( $classes ) {
		// Get Customizer settings
		$sundara_settings = get_option( 'sundara_settings' );
		
		$page_gradient 	   = 'enable';
		$unique_scrollbar  = 'enable';
		$blog_shadow  	   = 'enable';
		$sidebar_gradient  = 'enable';
		
		if ( isset( $sundara_settings['page_gradient'] ) ) {
			$page_gradient = $sundara_settings['page_gradient'];
		}
		
		if ( isset( $sundara_settings['unique_scrollbar'] ) ) {
			$unique_scrollbar = $sundara_settings['unique_scrollbar'];
		}
		
		if ( isset( $sundara_settings['blog_shadow'] ) ) {
			$blog_shadow = $sundara_settings['blog_shadow'];
		}
		
		if ( isset( $sundara_settings['sidebar_gradient'] ) ) {
			$sidebar_gradient = $sundara_settings['sidebar_gradient'];
		}
		
		// Page Gradient
		if ( $page_gradient != 'disable' ) {
			$classes[] = 'sundara-page-gradient';
		}
		
		// Unique scrollbar
		if ( $unique_scrollbar != 'disable' ) {
			$classes[] = 'sundara-unique-scrollbar';
		}
		
		// Blog image shadow
		if ( $blog_shadow != 'disable' ) {
			$classes[] = 'sundara-bis';
		}
		
		// Sidebar gradient
		if ( $sidebar_gradient != 'disable' ) {
			$classes[] = 'sundara-sidebar-gradient';
		}
		
		return $classes;
	}
}
